scicloj.ml.xgboost

Require this namespace to get xgboost support for classification and regression. Defines a full range of xgboost model definitions and supports xgboost explain functionality.

Require this namespace to get xgboost support for classification and regression.
Defines a full range of xgboost model definitions and supports xgboost explain
functionality.
raw docstring

->dmatrixclj

(->dmatrix feature-ds target-ds weight-ds sparse-column n-sparse-columns)
source

dataset->dmatrixclj

(dataset->dmatrix feature-ds)
(dataset->dmatrix feature-ds target-ds)
(dataset->dmatrix feature-ds target-ds weights-ds)

Dataset is a sequence of maps. Each contains a feature key. Returns a dmatrix.

Dataset is a sequence of maps.  Each contains a feature key.
Returns a dmatrix.
sourceraw docstring

objective-typesclj

source

sparse-feature->dmatrixclj

(sparse-feature->dmatrix feature-ds
                         target-ds
                         weight-ds
                         sparse-column
                         n-sparse-columns)

converts columns containing smile.util.SparseArray to a sparse dmatrix

converts columns containing smile.util.SparseArray to a sparse dmatrix
sourceraw docstring

tidy-text-bow-ds->dmatrixclj

(tidy-text-bow-ds->dmatrix feature-ds target-ds text-feature-column n-col)
source

trainclj

(train feature-ds label-ds options)
source

train-from-dmatrixclj

(train-from-dmatrix train-dmat-map
                    feature-cnames
                    target-cnames
                    options
                    label-map
                    objective)
source

cljdoc builds & hosts documentation for Clojure/Script libraries